Skip to contents

Raised when configuration parameters are invalid, missing, or inconsistent. This is a fatal error that stops the entire simulation run.

Usage

bayesim_config_error(message, call = NULL)

Arguments

message

The error message

call

The call that caused the error (optional)

Value

An error condition object with class c("bayesim_config_error", "bayesim_error", "error", "condition")

See also