Skip to contents

Raised when data generation or validation fails for a specific task. This is a task-level recoverable error that allows the simulation to continue with other tasks.

Usage

bayesim_data_error(message, call = NULL)

Arguments

message

The error message

call

The call that caused the error (optional)

Value

An error condition object with class c("bayesim_data_error", "bayesim_error", "error", "condition")