Converts retention profile name or explicit vector to canonical form. If a profile name is provided, returns the corresponding options. If explicit options are provided, validates them and returns only valid ones.
Examples
if (FALSE) { # \dontrun{
resolve_retention("minimal")
resolve_retention(c("metrics", "draws"))
} # }