Restores .Random.seed from a precomputed stream. Call this at the start of each worker task.
Examples
if (FALSE) { # \dontrun{
streams <- create_task_rng_streams(42, 10)
set_task_rng(streams[[1]])
} # }
Restores .Random.seed from a precomputed stream. Call this at the start of each worker task.
if (FALSE) { # \dontrun{
streams <- create_task_rng_streams(42, 10)
set_task_rng(streams[[1]])
} # }