Removes fields from fit result based on retention policy to reduce
memory footprint.
Usage
apply_fit_retention(fit_result, retain, data_bundle = NULL)
Arguments
- fit_result
A bayesim_fit_result object
- retain
Character vector of retention options specifying what to keep
- data_bundle
Ignored. Retained for backward compatibility.
Value
Modified bayesim_fit_result object with non-retained fields removed