R/errors.R
bayesim_config_error.Rd
Raised when configuration parameters are invalid, missing, or inconsistent. This is a fatal error that stops the entire simulation run.
bayesim_config_error(message, call = NULL)
The error message
The call that caused the error (optional)
An error condition object with class c("bayesim_config_error", "bayesim_error", "error", "condition")
is_fatal_error()