Raised when data generation or validation fails for a specific task. This is a task-level recoverable error that allows the simulation to continue with other tasks.
Value
An error condition object with class c("bayesim_data_error", "bayesim_error", "error", "condition")