Raised when metric computation fails for a specific task, such as undefined metrics for edge cases. This is a task-level recoverable error that allows the simulation to continue with other tasks.
Value
An error condition object with class c("bayesim_metric_error", "bayesim_error", "error", "condition")