Converts retention profile name or explicit vector to canonical form. If a profile name is provided, returns the corresponding options. If explicit options are provided, validates them and returns only valid ones.
Examples
resolve_retention("minimal")
#> [1] "metrics"
resolve_retention(c("metrics", "draws"))
#> [1] "metrics" "draws"